==> openeclass-4.0.2.zip: openeclass-4.0.2/lang/en/common.inc.php <==
<?php
/*
 *  ========================================================================
 *  * Open eClass
 *  * E-learning and Course Management System
 *  * ========================================================================
 *  * Copyright 2003-2024, Greek Universities Network - GUnet
 *  *
 *  * Open eClass is an open platform distributed in the hope that it will
 *  * be useful (without any warranty), under the terms of the GNU (General
 *  * Public License) as published by the Free Software Foundation.
 *  * The full license can be read in "/info/license/license_gpl.txt".
 *  *
 *  * Contact address: GUnet Asynchronous eLearning Group
 *  *                  e-mail: info@openeclass.org
 *  * ========================================================================
 *
 */

// Message file for language en
// Generated 2024-01-19 17:14:50

$langCourse = "Course";
$langEclass = "E-Learning Platform";
$langTeacher = "Teacher";
$langOfTeacher = "Teacher";
$langTeachers = "Teachers";
$langOfTeachers = "Teachers'";
$langsTeacher = "teacher";
$langsOfTeacher = "teacher";
$langsTeachers = "teachers";
$langsOfTeachers = "teachers'";
$langStudent = "Student";
$langOfStudent = "Student";
$langStudents = "Students";
$langOfStudents = "Students";
$langsStudent = "student";
$langsOfStudent = "student";
$langsStudents = "students";
$langsOfStudents = "students";
$langsOfStudentss = "students";
$langsstudent_acc = $langsStudent;
$langGuest = "Guest User";
$langGuests = "Guest Users";
$langFaculty = "Category";
$langOfFaculty = "Category";
$langOfFaculties = "Categories";
$langFaculties = "Categories";
$langsFaculty = "category";
$langsFaculties = "categories";
$langpres = "Undergraduate";
$langposts = "Postgraduate";
$langothers = "Other";
$langpre = "Undergraduate";
$langpost = "Postgraduate";
$langother = "Other";
$langInfoAbout = "The <strong>$siteName</strong> platform is a complete Course Management System that supports Asynchronous eLearning Services via a simple web browser. Its goal is the incorporation and constructive use of the Internet and web technologies in the teaching and learning process. It supports the electronic management, storage and presentation of teaching materials, independently of the spatial and time limiting factors of conventional teaching and creating the necessary conditions for a dynamic teaching environment.";
$langExtrasLeft = '';
$langExtrasRight = '';
$langCourses = "Courses";
$langGroupTutor = "Group Tutor";
$langEditor = "Tutor Assistant";
$langOfEditor = "Tutor Assistant";
$langsEditor = "tutor assistant";
$langsOfEditor = "tutor assistant";
$langsOfGroupTutor = "group tutor";
$langOfCourse = "Course";
$langOfCourses = "Courses";
$langsCourse = "course";
$langsCourses = "courses";
$langsOfCourse = "course";
$langsOfCourses = "courses";
$langsOfFaculty = "category";
$langCourseAdmin = "Admin";
$langOfCourseAdmin = "Admin";
$langCourseAdmins = "Admins";
$langOfCourseAdmins = "Admins";
$langsCourseAdmin = "admin";
$langsOfCourseAdmin = "admin";
$langsCourseAdmins = "admins";
$langsOfCourseAdmins = "admins";
$langCourseAdminTeacher = "Admin - Teacher";
$langOfCourseAdminTeacher = "Admin - Teacher";
$langCourseAdminTeachers = "Admins - Teachers";
$langOfCourseAdminTeachers = "Admins - Teachers";
$langsCourseAdminTeacher = "admin - teacher";
$langsOfCourseAdminTeacher = "admin - teacher";
$langsCourseAdminTeachers = "admins - teachers";
$langsOfCourseAdminTeachers = "admins - teachers";
$langCourseReviewer = "Reviewer";
$langOfCourseReviewer = "Reviewer";
$langsCourseReviewer = "reviewer";
$langsOfCourseReviewer = "reviewer";
$langCTeacher = "INSTRUCTOR";
$langCStudent = "LEARNER";
$langCStudent2 = "STUDENT";

==> openeclass-4.1.3.zip: openeclass-4.1.3/lang/en/common.inc.php <==
<?php
/*
 *  ========================================================================
 *  * Open eClass
 *  * E-learning and Course Management System
 *  * ========================================================================
 *  * Copyright 2003-2024, Greek Universities Network - GUnet
 *  *
 *  * Open eClass is an open platform distributed in the hope that it will
 *  * be useful (without any warranty), under the terms of the GNU (General
 *  * Public License) as published by the Free Software Foundation.
 *  * The full license can be read in "/info/license/license_gpl.txt".
 *  *
 *  * Contact address: GUnet Asynchronous eLearning Group
 *  *                  e-mail: info@openeclass.org
 *  * ========================================================================
 *
 */

// Message file for language en
// Generated 2024-01-19 17:14:50

$langCourse = "Course";
$langEclass = "E-Learning Platform";
$langTeacher = "Teacher";
$langOfTeacher = "Teacher";
$langTeachers = "Teachers";
$langOfTeachers = "Teachers'";
$langsTeacher = "teacher";
$langsOfTeacher = "teacher";
$langsTeachers = "teachers";
$langsOfTeachers = "teachers'";
$langStudent = "Student";
$langOfStudent = "Student";
$langStudents = "Students";
$langOfStudents = "Students";
$langsStudent = "student";
$langsOfStudent = "student";
$langsStudents = "students";
$langsOfStudents = "students";
$langsOfStudentss = "students";
$langsstudent_acc = $langsStudent;
$langGuest = "Guest User";
$langGuests = "Guest Users";
$langFaculty = "Category";
$langOfFaculty = "Category";
$langOfFaculties = "Categories";
$langFaculties = "Categories";
$langsFaculty = "category";
$langsFaculties = "categories";
$langpres = "Undergraduate";
$langposts = "Postgraduate";
$langothers = "Other";
$langpre = "Undergraduate";
$langpost = "Postgraduate";
$langother = "Other";
$langInfoAbout = "The <strong>$siteName</strong> platform is a complete Course Management System that supports Asynchronous eLearning Services via a simple web browser. Its goal is the incorporation and constructive use of the Internet and web technologies in the teaching and learning process. It supports the electronic management, storage and presentation of teaching materials, independently of the spatial and time limiting factors of conventional teaching and creating the necessary conditions for a dynamic teaching environment.";
$langExtrasLeft = '';
$langExtrasRight = '';
$langCourses = "Courses";
$langGroupTutor = "Group Tutor";
$langEditor = "Tutor Assistant";
$langOfEditor = "Tutor Assistant";
$langsEditor = "tutor assistant";
$langsOfEditor = "tutor assistant";
$langsOfGroupTutor = "group tutor";
$langOfCourse = "Course";
$langOfCourses = "Courses";
$langsCourse = "course";
$langsCourses = "courses";
$langsOfCourse = "course";
$langsOfCourses = "courses";
$langsOfFaculty = "category";
$langCourseAdmin = "Admin";
$langOfCourseAdmin = "Admin";
$langCourseAdmins = "Admins";
$langOfCourseAdmins = "Admins";
$langsCourseAdmin = "admin";
$langsOfCourseAdmin = "admin";
$langsCourseAdmins = "admins";
$langsOfCourseAdmins = "admins";
$langCourseAdminTeacher = "Admin - Teacher";
$langOfCourseAdminTeacher = "Admin - Teacher";
$langCourseAdminTeachers = "Admins - Teachers";
$langOfCourseAdminTeachers = "Admins - Teachers";
$langsCourseAdminTeacher = "admin - teacher";
$langsOfCourseAdminTeacher = "admin - teacher";
$langsCourseAdminTeachers = "admins - teachers";
$langsOfCourseAdminTeachers = "admins - teachers";
$langCourseReviewer = "Reviewer";
$langOfCourseReviewer = "Reviewer";
$langsCourseReviewer = "reviewer";
$langsOfCourseReviewer = "reviewer";
$langCTeacher = "INSTRUCTOR";
$langCStudent = "LEARNER";
$langCStudent2 = "STUDENT";

$langAlignment = "Alignment";
$langWidth = "Width";
$langAlignLeft = "Left";
$langAlignCenter = "Center";
$langAlignRight = "Right";
